/*
 语言转换函数
 移植自M5.3EN, 修改了Cookie设置(为各平台一致,单独language字段,不再使用COOKIE集)
 2014-11-18 by xgx
*/
(function () {
    let languageList = ['zh-CN', 'en-US'];	//语言列表
    let defaultLanguage = 'en-US';		//默认语言
    let enContextCls = 'global-en-context';
    let formatArgsStore;
    let locationStore;
    let currentLanguage;

    if (document.documentElement.className.indexOf(enContextCls) >= 0) {
        return;
    }

    // 判断是否是字符串(不能用is内的判断，时序问题)
    let isString = function (s) {
        return (typeof s === 'string') || s instanceof String;
    };

    //语言包使用的是HTML语法格式，需转换成JavaScript String格式
    let jsString = (function () {
        let rs = [/&quot;/g, /&lt;/g, /&gt;/g, /&amp;/g];
        return function (str) {
            return String(str).replace(rs[0], '"').replace(rs[1], '<')
                .replace(rs[2], '>')
                .replace(rs[3], '&');
        };
    })();

    //HTML代码中存在<br>等情况，需要转换成HTML String格式
    let htmlKey = (function () {
        let rs = [/&/g, /</g, />/g, /"/g];
        return function (str) {
            return String(str).replace(rs[0], '&amp;').replace(rs[1], '&lt;')
                .replace(rs[2], '&gt;')
                .replace(rs[3], '&quot;');
        };
    })();

    //HTML中存在&amp;nbsp;等情况的转义，需要转换成&nbsp;
    let htmlString = (function () {
        let rs = [/&lt;/g, /&gt;/g, /&amp;/g];
        return function (str) {
            return String(str).replace(rs[0], '<').replace(rs[1], '>')
                .replace(rs[2], '&');
        };
    })();

    /*支持扩展语言包变量 window.LanguageExpand 示例：window.LanguageExpand = {
            zh-CN: {
                'Key1': 'Value1',
                'Key2': 'Value2'
            }
        }
    */
    function _init () {
        if (!window.LANG) {
            window.LANG = {};
        }
        if (window.LanguageExpand && typeof window.LanguageExpand == 'object') {
            let pack = window.LanguageExpand[window.language];
            if (pack && typeof pack == 'object') {
                for (let prop in pack) {
                    if (pack.hasOwnProperty(prop)) {
                        window.LANG[prop] = pack[prop];
                    }
                }
            }
            delete window.LanguageExpand;
        }
    }
    //输出JavaScript多语言文字
    window.tr = function (json_key) {
        if (!isString(json_key)) { // 非字符串则直接返回
            return json_key;
        }
        _init();

        // 文字前后存在空格,去空格后再匹配翻译
        let trimPattern = /^\s*(.*?)\s*$/;
        let matchArr = json_key.match(trimPattern);
        let trimmedJsonKey = matchArr === null ? json_key : matchArr[1];             // 文字前后存在空格,去空格后的文字

        let result = window.LANG[trimmedJsonKey];

        if (result === null && json_key.length > 16) {	//编写Key，前8个字符+后8个字符
            result = window.LANG[json_key.substr(0, 8) + '+' + json_key.substr(json_key.length - 8)];
        }
        if (!result) {
            result = json_key; // 未翻译的直接显示中文
        }


        result = result.replace(/\{#[\d]+\}/g, '');

        // 还原文字前后的空格
        result = json_key.replace(trimmedJsonKey, result);

        if (arguments.length > 1) {
            let values = Array.prototype.slice.call(arguments, 1);
            return jsString(result.replace(/\{(\d+)\}/g, (m, i) => {
                return values[i] == null ? '' : values[i];
            }));
        } else {
            return jsString(result);
        }
    };

    // 统一控制台和portal的翻译函数
    // to do 后续portal tr()都被替换成_()时，window.tr函数可以删除
    window._ = window.tr;

    //输出HTML多语言文字（主要是放弃处理转义符）
    window.htmltr = function (json_key) {
        _init();
        let html_key = htmlKey(json_key);
        let result = window.LANG[html_key];
        if (result == null && html_key.length > 16) {	//编写Key，前8个字符+后8个字符
            result = window.LANG[html_key.substr(0, 8) + '+' + html_key.substr(html_key.length - 8)];
        }
        if (result == null || result === '') {
            result = json_key;
        }
        result = result.replace(/\{#[\d]+\}/g, '');
        if (arguments.length > 1) {
            let values = Array.prototype.slice.call(arguments, 1);
            return htmlString(result.replace(/\{(\d+)\}/g, (m, i) => {
                return values[i] == null ? '' : values[i];
            }));
        } else {
            return htmlString(result);
        }
    };
    //格式化字符串
    window.format = function (str) {
        if (arguments.length > 1) {
            let values = Array.prototype.slice.call(arguments, 1);
            return str.replace(/\{(\d+)\}/g, (m, i) => {
                return values[i] == null ? '' : values[i];
            });
        } else {
            return str;
        }
    };
    //内部函数，处理自定义HTML属性输出
    function _setLang () {
        if (document.body) {
            let bodyClass = document.body.className;
            //去除其他语言的classname
            for (var i = 0, len = languageList.length; i < len; i++) {
                bodyClass = bodyClass.replace(languageList[i], '');
            }
            bodyClass += (' ' + window.language);
            document.body.className = bodyClass;
        }
        let els = document.getElementsByTagName('*');
        let nameArr = ['html', 'value', 'title', 'alt'];
        let _els = [];
        for (var i = 0, len = els.length; i < len; i++) {	//注意：getElementsByTagName('*')返回的是可变列表，必需先转成数组
            _els[i] = els[i];
        }
        for (var i = 0, len = _els.length; i < len; i++) {
            let el = _els[i];
            for (let j = 0, jlen = nameArr.length; j < jlen; j++) {
                let name = nameArr[j];
                let _name = '_' + name;
                let _formatArgsName = _name + 'FormatArgs';
                let _index = 0;
                let _el = null;
                let args = null;
                let text = null;
                let formatArgsEl = null;
                if (el.getAttribute(_name)) {
                    if (el.getAttribute(_formatArgsName)) {
                        args = formatArgsStore[el.getAttribute(_formatArgsName)];	//正常的字符串，可以用变量声明
                        if (args == null) {
                            formatArgsEl = document.getElementById(el.getAttribute(_formatArgsName));	//带换行的字符串，请使用元素声明
                            if (formatArgsEl && formatArgsEl.childNodes.length > 0) {
                                args = [];
                                _index = 0;
                                for (let x = 0, xlen = formatArgsEl.childNodes.length; x < xlen; x++) {
                                    _el = formatArgsEl.childNodes[x];
                                    if (_el && _el.tagName) {
                                        args[_index] = _el.innerHTML;
                                        _index++;
                                    }
                                }
                            }
                        }
                    }
                    if (args != null) {
                        if (Object.prototype.toString.apply(args) === '[object Array]') {
                            text = htmltr.apply(window, [el.getAttribute(_name)].concat(args));
                        } else {
                            text = htmltr(el.getAttribute(_name), args);
                        }
                    } else {
                        text = htmltr(el.getAttribute(_name));
                    }
                    if (name === 'html') {
                        el.innerHTML = text;
                    } else {
                        el.setAttribute(name, text);
                    }
                }
            }
        }
        //设置title，兼容IE
        let title = document.getElementById('titleInnerHTML');
        if (title) {
            document.title = tr(title.innerHTML);
        }
    }
    //获取URL参数
    function _request (name) {
        if (!locationStore) {
            let search = window.location.search.substr(1); // 存在信任窗口则使用top，反之使用window
            let store = {};
            let joinKey = '&';
            let equalKey = '=';
            let i = 0;
            let len = search.length;
            while (i < len) {
                let index = search.indexOf(joinKey, i);
                let key;
                let value;
                let equalIndex = -1;
                let item;
                if (index !== -1) {
                    item = search.substr(i, index - i);
                    i = index + joinKey.length;
                } else {
                    item = search.substr(i);
                    i = search.length;
                }
                equalIndex = item.indexOf(equalKey);
                if (equalIndex !== -1) {
                    key = item.substr(0, equalIndex);
                    value = item.substr(equalIndex + equalKey.length);
                    try {
                        store[key.toLowerCase()] = decodeURIComponent(value);
                    } catch (ex) {
                        store[key.toLowerCase()] = value;
                    }
                }
            }
            locationStore = store;
        }
        return !name ? locationStore : locationStore[String(name).toLowerCase()];
    }
    /*
        @ formatArgs 格式化参数，示例：{
                                        a: ['<a href="">', '</a>'],
                                        b: ['<span>', '</span>']
                                    }
    */
    window.setLang = function (formatArgs) {
        formatArgsStore = formatArgs || {};
        if (_getCookie('language') && !window.LANG) {	//延时处理
            if (window.attachEvent) {
                window.attachEvent('onload', _setLang);
            } else {
                window.addEventListener('load', _setLang, false);
            }
        } else {
            _setLang();
        }
    };
    //切换语言language: zh-CN, en-US...
    window.toLang = function (language) {
        _setCookie('language', language, new Date(2999, 1, 1), '/', null, true);
        window.location.reload();
    };

    window.isEnglish = function () { // 判断英文环境
        return currentLanguage === 'en-US'; // 规避cookie在另外标签修改后，前端出现部分英文部分中文情况
    };
    window.getLanguage = function(){ // 获取当前语言环境
        return currentLanguage
    };
    function _getCookie (name) {
        let arg = name + '=';
        let alen = arg.length;
        let cookieObj = top.document.cookie; // 获取顶层语言
        let clen = cookieObj.length;
        let ret = '';
        let i = 0;
        while (i < clen) {
            let j = i + alen;
            if (document.cookie.substring(i, j) === arg) {
                let index = document.cookie.indexOf(';', j);
                if (index === -1) {
                    index = clen;
                }
                ret = unescape(document.cookie.substring(j, index));
            }
            i = document.cookie.indexOf(' ', i) + 1;
            if (i === 0) {
                break;
            }
        }
        return ret;
    }
    function _setCookie (name, value) {
        let argv = arguments;
        let argc = arguments.length;
        let expires = (argc > 2) ? argv[2] : null;
        let path = (argc > 3) ? argv[3] : '/';
        let domain = (argc > 4) ? argv[4] : null;
        let secure = (argc > 5) ? argv[5] : false;
        document.cookie = name + '=' + escape(value) + ((expires === null) ? '' : ('; expires=' + expires.toGMTString())) + ((path === null) ? '' : ('; path=' + path)) + ((domain === null) ? '' : ('; domain=' + domain)) + ((secure === true) ? '; secure' : '');
    }
    currentLanguage = _request('lang') || _getCookie('language'); // 优先级：URL传参->cookie

    if (!currentLanguage) {

        currentLanguage = String(window.navigator.language || window.navigator.systemLanguage || window.navigator.userLanguage || window.navigator.browserLanguage).toLowerCase();

        switch (currentLanguage) {
            case 'zh-cn':
            case 'zh':  // 兼容chrome 68
                currentLanguage = 'zh-CN'; break;
            case '': //获取不到语言的时候根据版本选择语言
                if (window.LANG_VERSION && window.LANG_VERSION.isInternational) {
                    currentLanguage = 'en-US';
                } else {
                    currentLanguage = 'zh-CN';
                }
                break;
            default:
                currentLanguage = defaultLanguage; break;
        }
    } else {
        currentLanguage = currentLanguage.substr(0, 2).toLocaleLowerCase() + '-' + currentLanguage.substr(3, 2).toUpperCase();
    }

    //根据语言列表选择语言, cookie传来的值不可信任
    let languageName = defaultLanguage;
    for (let i = 0, len = languageList.length; i < len; i++) {
        if (languageList[i] === currentLanguage) {
            languageName = languageList[i];
            break;
        }
    }

    window.language = languageName;
    _setCookie('language', languageName, new Date(2999, 1, 1), '/', null, true);
    /* //统一为单独cookie 不再同步 2014-11-18 by xgx
    if(perCookie.getBaseCookie('language')){	//ios同时可能存在两个Cookie,需要同步
        perCookie.setBaseCookie('language', window.language);
    }
    */
    let isEn = languageName !== 'zh-CN';
    if (!isEn) {
        return;
    }
    document.documentElement.className += ' ' + enContextCls;
    if (location.pathname.indexOf('service_center.html') < 0 && typeof notLoadLangPack === 'undefined') {

        // protocol === file为本地页面
        let isNapInformationPage = location.pathname.indexOf('nap_information') >= 0; // nap_information目录需要往上找一层
        var path = '';
        path = isNapInformationPage ? ('../' + path) : path;
        // 解决异步script无法document.write的问题x
        document.write(['<script src="', path, 'i18n/language.', languageName, '.js?v=', SF_VERSION, '"><\/script>'].join(''));
    }

})();
/*end M6.8 EN*/
