#!/bin/bash

# 说明：执行脚本，第一参数为执行命令
#atrust的东西都安装在/usr/share/aTrust目录下
PATH=/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/X11/bin:$PATH
export PATH
LOGFILE="/tmp/com.sangfor.aTrustShellExec.script.start.log"

touch $LOGFILE
chmod 777 $LOGFILE
echo "start...." >$LOGFILE
date >>$LOGFILE

username=""
userUid=""

#是否是可登陆的用户
can_login_user()
{
  if [ $# -lt 1 ]; then
    echo "can_login_user params error" >>$LOGFILE
    return 1
  fi
  local username_in=$1
  #检测用户名是否为空，以及是否是不可登录用户（当图形化界面没有用户登录时，上面可能会获取到图形管理用户，而该用户时不可登录的）
  if [ -z "${username_in}" ] || (getent passwd | awk -F ':' 'match($7,/[(nologin)|(false)]$/){print $1}' | grep -qw "${username_in}"); then
    echo "username_in:${username_in} is empty or belongs to nologin users, will not start the tray" >>$LOGFILE
    return 1
  fi
  return 0
}

oldIFS=IFS
#获取用户名和显示位置
declare -A property
for session in $(loginctl --no-legend list-sessions | awk '{ print $1 }' ); do

  while IFS="=" read key value ; do
    property[${key}]="${value}"
  done < <(loginctl show-session "${session}")

  if [ "${property[Type]}" = "x11" ] || [ "${property[Type]}" = "wayland" ]; then
    display=${property[Display]}
    userUid=${property[User]}
    tmp_user=$(id -nu "${userUid}")
    echo "get userUid:${userUid} and tmp_user:${tmp_user}" >>$LOGFILE
    if [ "${property[Active]}" = "yes" ] && can_login_user "${tmp_user}";then
      #通过了才给赋值，否则后面的判空会没有意义
      username=${tmp_user}
      break;
    fi
  fi
done

if [ "x${username}" == "x" ] || [ "${username}" == "root" ]; then
  echo "install can't get pc login name:${username}, can't install..." >>$LOGFILE
  exit 1
fi

#还原原始分割符
IFS=oldIFS
echo "current get username:<${username}> and display:<${display}>" >>$LOGFILE
if [ "$DISPLAY" == "" ]; then
  if [ "${display}" == "" ]; then
    #前面没有获取到，尝试使用w -h来获取，如果获取也失败，则使用默认的
    if (w -h |awk 'match($3,/^:[0-9]+/){print $1}' |grep -qw "${username}"); then
      display=$(w -h |grep ${username} |awk 'match($3,/^:[0-9]+/){print $3}' |head -n 1);
    else
      display=":0"
    fi
  fi
 	echo "no DISPLAY set, so get display:${display}" >>$LOGFILE
	export DISPLAY=${display}
fi

if [ "$HOME" == "" ] || [ "$HOME" == "/root" ]; then
  home_dir=$(getent passwd ${userUid} | awk -F ":" '{print $6}')
 	echo "no HOME set, so get login user:${username} and home_dir:${home_dir}" >>$LOGFILE
 	if [ -d "${home_dir}" ]; then
 	  export HOME=${home_dir}
 	else
 	  echo "${home_dir} not exist can not be continue" >>$LOGFILE
 	  exit 1
 	fi
fi

printenv >>$LOGFILE
umask u=rwx,g=rwx,o=rwx

FILE_PATH=${1}
if [ ! -f "${FILE_PATH}" ]; then
  echo "can't get ${FILE_PATH}, can't start aTrustInstaller..." >>$LOGFILE
  exit 1
fi
FILE_TYPE=$(xdg-mime query filetype "${FILE_PATH}")
OPEN_DESKTOP=$(xdg-mime query default "${FILE_TYPE}")
OPEN_DESKTOP_PATH="/usr/share/applications/${OPEN_DESKTOP}"
if [ ! -f "${OPEN_DESKTOP_PATH}" ]; then

  OPEN_DESKTOP_PATH="${HOME}/.local/share/applications/${OPEN_DESKTOP}"
  if [ ! -f "${OPEN_DESKTOP_PATH}" ]; then
    echo "can't get ${OPEN_DESKTOP}, can't exec shell..." >>$LOGFILE
    exit 1
  fi
fi

EXEC_CMD=$(awk '/^Exec=/ {sub("^Exec=", ""); gsub("%[cDdFfikmNnUuv]", "'"${FILE_PATH}"'"); print; exit}' "${OPEN_DESKTOP_PATH}")
echo "start cmd:${EXEC_CMD}" >>$LOGFILE
${EXEC_CMD} >>$LOGFILE 2>&1
start_ret=$?
if [ ${start_ret} -ne 0 ]
then
  echo "start error:${start_ret} !" >>$LOGFILE
  exit 1
fi

echo "start over!" >>$LOGFILE
date >>$LOGFILE

exit 0
