#!/bin/bash
# 根据用户名获取DISPLAY号，适配一般场景、xorg场景以及vnc场景

USERNAME=$1
if [ -z "$USERNAME" ]; then
	exit 1
fi

# TODO：VNC场景待验证
function get_user_vnc_display()
{
    # 获取指定用户的所有 Xvnc 进程 ID
    pids=$(pgrep -u "$USERNAME" Xvnc)
    # 遍历所有进程 ID，获取相应的 display
    for pid in $pids; do
        cmdline=$(tr '\0' ' ' < "/proc/$pid/cmdline")
        if [[ $cmdline == *'Xvnc'* && $cmdline == *'-desktop'* ]]; then
            echo "${cmdline#*-desktop }"
            return
        fi
    done

    # 获取指定用户的所有 Xtigervnc 进程 ID
    pids=$(pgrep -u "$USERNAME" Xtigervnc)
    # 遍历所有进程 ID，获取相应的 display
    for pid in $pids; do
        cmdline=$(tr '\0' ' ' < "/proc/$pid/cmdline")
        if [[ $cmdline == *'Xtigervnc'* && $cmdline == *'-desktop'* ]]; then
            echo "$cmdline" | sed -n 's/.*Xtigervnc \(:[0-9]\+\) -desktop.*/\1/p'
            return
        fi
    done
}


# 优先检查一般场景
COMMON_DISPLAY=$(who | awk '$1 == username && $2 ~ /^tty[0-9]+$/ && $NF ~ /\(:[0-9]+\)$/ {print $NF}' username="$USERNAME" | sort -u | sed 's/[\(\):]//g')
if [ -n "$COMMON_DISPLAY" ]; then
	echo "$COMMON_DISPLAY"
	exit 0
fi

# 一般场景为空，开始检查Xorg场景
XORG_DISPLAY=$(ps -eo user:100,cmd | awk '/Xorg :[0-9]+/ && $1==username {match($0, / :[0-9]+/); print substr($0, RSTART+2, RLENGTH-2)}' username="$USERNAME")
if [ -n "$XORG_DISPLAY" ]; then
	echo "$XORG_DISPLAY"
	exit 0
fi

# Xorg场景为空，开始检查VNC场景
VNC_DISPLAY=$(get_user_vnc_display)
if [ -n "$VNC_DISPLAY" ]; then
	echo "$VNC_DISPLAY"
	exit 0
fi

exit 1