#!/bin/bash

LOG_PATH="/tmp/aTrustInstallOut.log"
SHELL_PATH="/usr/share/sangfor/aTrust/resources/shell"
#CURRENT_ARCH="x86_64"

#日志输出函数
#参数1：[in]日志等级：Infor,Error
#参数2：[in]日志内容
log() {

  #参数处理
  if [ $# -lt 2 ]; then
    return 0
  fi
  LOG_LEV=$1
  LOG_FMT=$2
  shift 2

  if [ ! -f $LOG_PATH ]; then
    local log_dir=""
    log_dir=$(dirname $LOG_PATH)
    if [ ! -d "$log_dir" ]; then
      mkdir -p "$log_dir"
    fi
  fi

  if [ "$LOG_LEV" = "Error" ]; then
    echo "[$(date '+%Y-%m-%d %H:%M:%S')] [$LOG_LEV] ${LOG_FMT} $*"
    echo "[$(date '+%Y-%m-%d %H:%M:%S')] [$LOG_LEV] ${LOG_FMT}" "$@" >> $LOG_PATH
  elif [ "$LOG_LEV" = "Infor" ]; then
    echo "[$(date '+%Y-%m-%d %H:%M:%S')] [$LOG_LEV] ${LOG_FMT} $*"
    echo "[$(date '+%Y-%m-%d %H:%M:%S')] [$LOG_LEV] ${LOG_FMT}" "$@" >> $LOG_PATH
  fi
}

test_dpkg_running()
{
	local dpkg_status
	local wait_times
	wait_times=0
	dpkg_status=$( pgrep -c dpkg)
	while [ "$dpkg_status" -ne 0 ]
	do
		wait_times=$((wait_times+1))
		sleep 1
		dpkg_status=$( pgrep -c dpkg)
		#避免dpkg出现问题，脚本长时间阻塞。
		if [ "${wait_times}" -gt 80 ]
		then
			log "Error" "wait dpkg runnig too long,please check the dpkg status and reinstall"
			exit 1
		fi
	done
}

install_vdi()
{
	#检查是否有dpkg程序正在安装。
    test_dpkg_running

    log "Infor" "start install vdi..."
    if ! dpkg -i ${SHELL_PATH}/vdi-linux-client-*.deb;then
        log "Error" "install vdi deb file failed,check the instll file"
		exit 1
    fi
    log "Infor" "end install vdi..."
}

main() {

    log "Infor" "will install vdi package"
    install_vdi
}


main
exit 0
